@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301  USA.
 
    Author: Bastien Nocera <hadess@hadess.net>
  */
@@ -50,8 +50,6 @@
 #define XSCREENSAVER_MIN_TIMEOUT 60
 
 static GObjectClass *parent_class = NULL;
-static void totem_scrsaver_class_init (TotemScrsaverClass *class);
-static void totem_scrsaver_init       (TotemScrsaver      *parser);
 static void totem_scrsaver_finalize   (GObject *object);
 
 
@@ -296,13 +294,12 @@ screensaver_disable_x11 (TotemScrsaver *scr)
 				&scr->priv->allow_exposures);
 		XUnlockDisplay (GDK_DISPLAY());
 
-		if (scr->priv->timeout != 0)
-		{
-			g_timeout_add (scr->priv->timeout / 2 * 1000,
-					(GSourceFunc) fake_event, scr);
+		if (scr->priv->timeout != 0) {
+			g_timeout_add_seconds (scr->priv->timeout / 2,
+					       (GSourceFunc) fake_event, scr);
 		} else {
-			g_timeout_add (XSCREENSAVER_MIN_TIMEOUT / 2 * 1000,
-					(GSourceFunc) fake_event, scr);
+			g_timeout_add_seconds (XSCREENSAVER_MIN_TIMEOUT / 2,
+					       (GSourceFunc) fake_event, scr);
 		}
 
 		return;
@@ -432,8 +429,7 @@ totem_scrsaver_set_state (TotemScrsaver *scr, gboolean enable)
 	if (scr->priv->disabled == !enable)
 		return;
 
-	scr->priv->disabled = !enable;
-	if (scr->priv->disabled != FALSE)
+	if (enable == FALSE)
 		totem_scrsaver_disable (scr);
 	else
 		totem_scrsaver_enable (scr);
