@@ -5,9 +5,12 @@ import xmlrpclib
 import threading
 import xdg.BaseDirectory
 from os import sep
+import gettext
 
 from hash import hashFile
 
+D_ = gettext.dgettext
+
 USER_AGENT = 'Totem'
 OK200 = '200 OK'
 TOTEM_REMOTE_COMMAND_REPLACE = 14
@@ -343,7 +346,9 @@ class OpenSubtitles(totem.Plugin):
 
         # Set up and populate the languages combobox
         renderer = gtk.CellRendererText()
-        combobox.set_model(languages)
+        sorted_languages = gtk.TreeModelSort(languages)
+        sorted_languages.set_sort_column_id(0, gtk.SORT_ASCENDING)
+        combobox.set_model(sorted_languages)
         combobox.pack_start(renderer, True)
         combobox.add_attribute(renderer, 'text', 0)
 
@@ -351,7 +356,8 @@ class OpenSubtitles(totem.Plugin):
         for lang in LANGUAGES_STR:
             it = languages.append(lang)
             if LANGUAGES[lang[1]] == self.model.lang:
-                combobox.set_active_iter(it)
+                parentit = sorted_languages.convert_child_iter_to_iter (None, it)
+                combobox.set_active_iter(parentit)
 
         # Set up the results treeview 
         renderer = gtk.CellRendererText()
@@ -502,7 +508,7 @@ class OpenSubtitles(totem.Plugin):
             if not filename:
                 directory = gio.File(xdg.BaseDirectory.xdg_cache_home + sep + 'totem' + sep + 'subtitles' + sep) 
                 if not directory.query_exists():
-                    directory.make_directory()
+                    directory.make_directory_with_parents()
 
                 file = gio.File(self.filename)
                 movie_name = file.get_basename().rpartition('.')[0]
