@@ -43,7 +43,6 @@ void eject_action_callback (GtkAction *action, Totem *totem);
 void properties_action_callback (GtkAction *action, Totem *totem);
 void play_action_callback (GtkAction *action, Totem *totem);
 void quit_action_callback (GtkAction *action, Totem *totem);
-void take_screenshot_action_callback (GtkAction *action, Totem *totem);
 void preferences_action_callback (GtkAction *action, Totem *totem);
 void fullscreen_action_callback (GtkAction *action, Totem *totem);
 void zoom_1_2_action_callback (GtkAction *action, Totem *totem);
@@ -554,7 +553,7 @@ on_recent_file_item_activated (GtkAction *action,
 	recent_info = g_object_get_data (G_OBJECT (action), "recent-info");
 	uri = gtk_recent_info_get_uri (recent_info);
 
-	totem_add_to_playlist_and_play (totem, uri, NULL, TRUE);
+	totem_add_to_playlist_and_play (totem, uri, NULL, FALSE);
 }
 
 static gint
@@ -803,12 +802,22 @@ add_drive_to_menu (GDrive *drive, guint position, Totem *totem)
 		/* Work out an icon to display */
 		icon = g_volume_get_icon (i->data);
 		icon_name = NULL;
-		icon_names = g_themed_icon_get_names (G_THEMED_ICON (icon));
 
-		for (j = 0; icon_names[j] != NULL; j++) {
-			icon_name = icon_names[j];
-			if (gtk_icon_theme_has_icon (theme, icon_name) != FALSE)
-				break;
+		if (G_IS_EMBLEMED_ICON (icon) != FALSE) {
+			GIcon *new_icon;
+			new_icon = g_emblemed_icon_get_icon (G_EMBLEMED_ICON (icon));
+			g_object_unref (icon);
+			icon = g_object_ref (new_icon);
+		}
+
+		if (G_IS_THEMED_ICON (icon)) {
+			icon_names = g_themed_icon_get_names (G_THEMED_ICON (icon));
+
+			for (j = 0; icon_names[j] != NULL; j++) {
+				icon_name = icon_names[j];
+				if (gtk_icon_theme_has_icon (theme, icon_name) != FALSE)
+					break;
+			}
 		}
 
 		/* Get the volume's pretty name for the menu label */
@@ -1011,18 +1020,12 @@ play_action_callback (GtkAction *action, Totem *totem)
 	totem_action_play_pause (totem);
 }
 
-void
+G_GNUC_NORETURN void
 quit_action_callback (GtkAction *action, Totem *totem)
 {
 	totem_action_exit (totem);
 }
 
-void
-take_screenshot_action_callback (GtkAction *action, Totem *totem)
-{
-	totem_action_take_screenshot (totem);
-}
-
 void
 preferences_action_callback (GtkAction *action, Totem *totem)
 {
